==> 1.1.7.tar.gz: t2code-alias/src/main/java/net/t2code/alias/Spigot/system/Load.java <==
package net.t2code.alias.Spigot.system;

import net.t2code.alias.Spigot.Main;
import net.t2code.alias.Spigot.cmdManagement.AliasCmdExecuter;
import net.t2code.alias.Spigot.cmdManagement.TabEvent;
import net.t2code.alias.Spigot.config.alias.CreateExampleAliasConfig;
import net.t2code.alias.Spigot.config.alias.SelectAlias;
import net.t2code.alias.Spigot.config.config.*;
import net.t2code.alias.Spigot.config.languages.LanguagesCreate;
import net.t2code.alias.Spigot.config.languages.SelectMessages;
import net.t2code.alias.Spigot.config.subAlias.CreateExampleSubAliasConfig;
import net.t2code.alias.Spigot.config.subAlias.SelectSubAlias;
import net.t2code.alias.Util;
import net.t2code.t2codelib.SPIGOT.api.messages.T2Ctemplate;
import net.t2code.t2codelib.SPIGOT.api.register.T2Cregister;
import net.t2code.t2codelib.SPIGOT.api.update.T2CupdateAPI;
import org.bukkit.Bukkit;

import java.io.File;
import java.util.List;

public class Load {
    private static final Main plugin = Main.getPlugin();

    public static void onLoad(String prefix, List<String> autor, String version, String spigot, String discord, int bstatsID) {
        Long long_ = T2Ctemplate.onLoadHeader(prefix, autor, version, spigot, discord);
        plugin.getCommand("t2code-alias").setExecutor(new AliasCmdExecuter());
        loadReload();
        T2CupdateAPI.onUpdateCheck(plugin,prefix,Util.getGit(),Util.getSpigotID(),Util.getDiscord(),
                SelectConfig.getUpdateCheckOnJoin(),SelectConfig.getUpdateCheckSeePreReleaseUpdates(),SelectConfig.getUpdateCheckTimeInterval());
        Bukkit.getServer().getPluginManager().registerEvents(new JoinEvent(), plugin);

        T2Ctemplate.onLoadFooter(prefix, long_, version);
        Metrics.Bstats(plugin, bstatsID);
    }

    public static void loadReload() {
        if (!new File(Main.getPath(), "config.yml").exists()) {
            try {
                CreateExampleAliasConfig.configCreate();
            } catch (Exception e) {
                e.printStackTrace();
            }
            try {
                CreateExampleSubAliasConfig.configCreate();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        try {
            plugin.saveResource("Alias/X_aliasDeclaration_X.yml", true);
        } catch (Exception e) {
            e.printStackTrace();
        }
        try {
            plugin.saveResource("SubAlias/X_subAliasDeclaration_X.yml", true);
        } catch (Exception e) {
            e.printStackTrace();
        }
        CreateConfig.configCreate();
        LanguagesCreate.langCreate();
        SelectConfig.onSelect();
        SelectMessages.onSelect(Util.getPrefix());
        T2Ctemplate.onLoadSeparateStroke(Util.getPrefix());
        SelectAlias.onSelect();
        T2Ctemplate.onLoadSeparateStroke(Util.getPrefix());
        SelectSubAlias.onSelect();
        SelectConfig.setConfigVersion();
        if (SelectConfig.getSubAliasTab()) {
            T2Cregister.listener(new TabEvent(), plugin);
        }

        if (SelectConfig.getBungee()) {
            Bukkit.getMessenger().registerOutgoingPluginChannel(plugin, "t2c:bcmd");
        }
        AliasRegisterPermissions.onPermRegister();
    }

}

==> 1.2.1.tar.gz: t2code-alias/src/main/java/net/t2code/alias/Spigot/system/Load.java <==
package net.t2code.alias.Spigot.system;

import net.t2code.alias.Spigot.Main;
import net.t2code.alias.Spigot.cmdManagement.AliasCmdExecuter;
import net.t2code.alias.Spigot.cmdManagement.TabEvent;
import net.t2code.alias.Spigot.config.alias.CreateExampleAliasConfig;
import net.t2code.alias.Spigot.config.alias.SelectAlias;
import net.t2code.alias.Spigot.config.config.*;
import net.t2code.alias.Spigot.config.languages.LanguagesCreate;
import net.t2code.alias.Spigot.config.languages.SelectMessages;
import net.t2code.alias.Spigot.config.subAlias.CreateExampleSubAliasConfig;
import net.t2code.alias.Spigot.config.subAlias.SelectSubAlias;
import net.t2code.alias.Spigot.listener.PluginEvents;
import net.t2code.alias.Util;
import net.t2code.t2codelib.SPIGOT.api.messages.T2Ctemplate;
import net.t2code.t2codelib.SPIGOT.api.register.T2Cregister;
import net.t2code.t2codelib.SPIGOT.api.update.T2CupdateAPI;
import net.t2code.t2codelib.SPIGOT.api.yaml.T2CLibConfig;
import org.bukkit.Bukkit;

import java.io.File;
import java.util.List;

public class Load {
    private static final Main plugin = Main.getPlugin();

    public static void onLoad(String prefix, List<String> autor, String version, String spigot, String discord, int bstatsID) {
        Long long_ = T2Ctemplate.onLoadHeader(prefix, autor, version, spigot, discord);
        plugin.getCommand("t2code-alias").setExecutor(new AliasCmdExecuter());
        loadReload();
        T2CupdateAPI.onUpdateCheck(plugin, prefix, Util.getGit(), Util.getSpigotID(), Util.getDiscord(),
                SelectConfig.getUpdateCheckOnJoin(), SelectConfig.getUpdateCheckSeePreReleaseUpdates(), SelectConfig.getUpdateCheckTimeInterval());

        T2Ctemplate.onLoadFooter(prefix, long_, version);
        T2Cregister.listener(new PluginEvents(), plugin);
        Metrics.Bstats(plugin, bstatsID);
    }

    public static void loadReload() {
        if (!new File(Main.getPath(), "config.yml").exists()) {
            try {
                CreateExampleAliasConfig.configCreate();
            } catch (Exception e) {
                e.printStackTrace();
            }
            try {
                CreateExampleSubAliasConfig.configCreate();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        try {
            plugin.saveResource("Alias/X_aliasDeclaration_X.yml", true);
        } catch (Exception e) {
            e.printStackTrace();
        }
        try {
            plugin.saveResource("SubAlias/X_subAliasDeclaration_X.yml", true);
        } catch (Exception e) {
            e.printStackTrace();
        }
        CreateConfig.configCreate();
        LanguagesCreate.langCreate();
        SelectConfig.onSelect();
        SelectMessages.onSelect(Util.getPrefix());
        T2Ctemplate.onLoadSeparateStroke(Util.getPrefix());
        SelectAlias.onSelect();
        T2Ctemplate.onLoadSeparateStroke(Util.getPrefix());
        SelectSubAlias.onSelect();
        SelectConfig.setConfigVersion();
        if (SelectConfig.getSubAliasTab()) {
            T2Cregister.listener(new TabEvent(), plugin);
        }

        if (T2CLibConfig.getBungee()) {
            Bukkit.getMessenger().registerOutgoingPluginChannel(plugin, "t2c:bcmd");
        }
        AliasRegisterPermissions.onPermRegister();
    }

}
